@@ -23,7 +23,9 @@ like allowed characters in version numbers, etc.
 import os
 import re
 
-from gbp.pkg import (PkgPolicy, compressor_opts)
+from gbp.errors import GbpError
+from gbp.pkg.pkgpolicy import PkgPolicy
+from gbp.pkg.compressor import Compressor
 
 
 class DebianPkgPolicy(PkgPolicy):
@@ -85,7 +87,10 @@ class DebianPkgPolicy(PkgPolicy):
         @return: the tarballs name corresponding to the input parameters
         @rtype: C{str}
         """
-        ext = compressor_opts[compression][1]
+        try:
+            ext = Compressor.Exts[compression]
+        except KeyError:
+            raise GbpError("Unknown compression type '%s'" % compression)
         sub = '-{0}'.format(component) if component else ''
         tarball = "%s_%s.orig%s.tar.%s" % (name, version, sub, ext)
         if dir:
